@@ -17,6 +17,8 @@ import json
 import os
 import re
 import sys
+import concurrent.futures
+
 
 # extras
 import boto3
@@ -613,6 +615,7 @@ class GimmeAWSCreds(object):
                 'links': {'appLink': self.config.app_url}
             }
             aws_results.append(new_app_entry)
+            self.ui.info("Authentication Success!")
 
         # Use the gimme_creds_lambda service
         else:
@@ -705,7 +708,7 @@ class GimmeAWSCreds(object):
             except ClientError as ex:
                 if 'requested DurationSeconds exceeds the MaxSessionDuration' in ex.response['Error']['Message']:
                     self.ui.warning(
-                        "The requested session duration was too long for this role.  Falling back to 1 hour.")
+                        "The requested session duration was too long for the role {}.  Falling back to 1 hour.".format(role.role))
                     aws_creds = self._get_sts_creds(
                         self.aws_partition,
                         self.saml_data['SAMLResponse'],
@@ -770,12 +773,19 @@ class GimmeAWSCreds(object):
 
     def iter_selected_aws_credentials(self):
         results = []
-        for role in self.aws_selected_roles:
+        aws_results = []
+
+        def generate_credentials_prepare_data(role):
             data = self.prepare_data(role, generate_credentials=True)
-            if not data:
+            return data
+
+        with concurrent.futures.ThreadPoolExecutor(max_workers=10) as executor:
+            aws_results = executor.map(generate_credentials_prepare_data, self.aws_selected_roles)
+        for ar in aws_results:
+            if not ar:
                 continue
-            results.append(data)
-            yield data
+            results.append(ar)
+            yield ar
 
         self._cache['selected_aws_credentials'] = results
 
@@ -819,6 +829,16 @@ class GimmeAWSCreds(object):
         if action == "json":
             self.ui.result(json.dumps(data))
             return
+        elif action == "windows":
+            self.ui.result("$env:AWS_ROLE_ARN=\"" + data['role']['arn']+"\"")
+            self.ui.result("$env:AWS_ACCESS_KEY_ID=\"" +
+                           data['credentials']['aws_access_key_id']+"\"")
+            self.ui.result("$env:AWS_SECRET_ACCESS_KEY=\"" +
+                           data['credentials']['aws_secret_access_key']+"\"")
+            self.ui.result("$env:AWS_SESSION_TOKEN=\"" +
+                           data['credentials']['aws_session_token']+"\"")
+            self.ui.result("$env:AWS_SECURITY_TOKEN=\"" +
+                           data['credentials']['aws_security_token']+"\"")
         else:
             # Defaults to `export` format
             self.ui.result("export AWS_ROLE_ARN=" + data['role']['arn'])
